==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/da/general.php <==
<?php

    return [
    'accessories'			=> 'Tilbehør',
    'activated'			    => 'Aktiveret',
    'accessory'				=> 'Tilbehør',
    'accessory_report'		=> 'Tilbehørsrapport',
    'action'                => 'Handling',
    'activity_report'		=> 'Aktivitetsrapport',
    'address'				=> 'Addresse',
    'admin'					=> 'Admin',
    'administrator'			=> 'Administrator',
    'add_seats'             => 'Tilføjede pladser',
    'all_assets'			=> 'Alle aktiver',
    'all'       			=> 'Alle',
    'archived'              => 'Arkiveret',
    'asset_models'			=> 'Aktiv Modeller',
    'asset_model'			=> 'Model',
    'asset'					=> 'Aktiv',
    'asset_report'          => 'Aktiv Rapport',
    'asset_tag'				=> 'Aktiv Mærkat',
    'assets_available'		=> 'aktiver tilgængelige',
    'audit'				    => 'Revidere',
    'audit_report'			=> 'Revisionslog',
    'assets'				=> 'Aktiver',
    'avatar_delete'         => 'Slet avatar',
    'avatar_upload'         => 'Upload Avatar',
    'back'      			=> 'Tilbage',
    'bad_data'      		=> 'Intet fundet. Måske dårlig data?',
    'bulkaudit'             => 'Bulk Audit',
    'bulkaudit_status'      => 'Revisionsstatus',
    'bulk_checkout'  		=> 'Masseudtjekning',
    'bystatus'              => 'efter status',
    'cancel'  				=> 'Annuller',
    'categories'			=> 'Kategorier',
    'category'				=> 'Kategori',
    'change' 		        => 'Ind ud',
    'changeemail'  			=> 'Skift email adresse',
    'changepassword'  		=> 'Skift adgangskode',
    'checkin'  				=> 'Tjek Ind',
    'checkin_from'  		=> 'Tjek ind fra',
    'checkout'  			=> 'Tjek Ud',
    'checkouts_count'       => 'Checkouts',
    'checkins_count'        => 'Checkins',
    'user_requests_count'   => 'Forespørgsler',
    'city'  				=> 'By',
	'click_here'			=> 'Klik her',
    'clear_selection'		=> 'Ryd valg',
    'companies'			    => 'Selskaber',
    'company'				=> 'Selskab',
    'component'			    => 'Komponent',
    'components'			=> 'Komponenter',
	'complete'				=> 'Komplet',
    'consumable'			=> 'forbrugsmateriale',
    'consumables'			=> 'Forbrugsstoffer',
    'country'  				=> 'Land',
    'create'				=> 'Opret ny',
    'created'               => 'Elementet er oprettet',
    'created_asset'			=> 'skabte aktiver',
    'created_at' 			=> 'Skabt den',
    'record_created' 		=> 'Record dannet',
    'updated_at' 			=> 'Opdateret kl',
    'currency'  			=> '$', // this is deprecated
    'current'  				=> 'Aktuelle',
    'custom_report'         => 'Tilpasset Aktiv Rapport',
    'dashboard'				=> 'Oversigtspanel',
    'days'      			=> 'dage',
    'days_to_next_audit'    => 'Dage til næste revision',
    'date'					=> 'Dato',
    'debug_warning'         => 'Advarsel!',
    'debug_warning_text'    => 'Denne applikation kører i produktionstilstand med debugging aktiveret. Dette kan udsætte følsomme data, hvis din ansøgning er tilgængelig for omverdenen. Deaktiver fejlsøgningsmodus ved at indstille værdien <code>APP_DEBUG</code> i din <code>.env</code> fil til <code>false</code>.',
    'delete'  				=> 'Slet',
    'delete_confirm'  		=> 'Er du sikker på at du vil slette :item?',
    'deleted'  				=> 'Slettet',
    'delete_seats'  		=> 'Slettede pladser',
    'departments'           => 'Afdelinger',
    'department'           => 'Afdeling',
    'deployed'				=> 'Implementeret',
    'depreciation_report'	=> 'Afskrivningsrapport',
    'details'               => 'Detaljer',
    'download'				=> 'Hent',
    'download_all'				=> 'Download alt',
    'depreciation'			=> 'Afskrivning',
    'editprofile'  			=> 'Ret Din Profil',
    'eol'					=> 'EOL',
    'email_domain'			=> 'Email domæne',
    'email_format'			=> 'Email formattering',
    'email_domain_help'		=> 'Dette bruges til at generere email-adresser ved importering',
    'filastname_format'			=> 'Fornavnskarakter Efternavn (jsmith@example.com)',
    'firstname_lastname_format'	=> 'Fornavn Efternavn (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'Fornavn Efternavn (jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  'Efternavn Første initial (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'Første bogstav i fornavn efternavn (jsmith@example.com)',
    'first'					=> 'Første',
    'firstnamelastname'     => 'Fornavn efternavn (janesmith@example.com)',
    'lastname_firstinitial' => 'Efternavn første bogstav i fornavn (smith_j@example.com)',
    'firstinitial.lastname' => 'Første bogstav i fornavn.efternavn (j.smith@example.com)',
    'firstnamelastinitial'  => 'Fornavn førstebogstav i efternavn (janes@example.com)',
    'first_name'			=> 'Fornavn',
    'first_name_format'		=> 'Fornavn (jane@example.com)',
    'files'                 => 'Filer',
    'file_name'				=> 'Fil',
    'file_type'             => 'Filtype',
    'file_uploads'			=> 'Filoverførsel',
    'generate'				=> 'Skab',
     'github_markdown'      => 'Dette felt tillader <a href="https://help.github.com/articles/github-flavored-markdown/">Github flavored markdown</a>.',
    'groups'				=> 'Grupper',
    'gravatar_email'        => 'Gravatar email addresse',
    'history'  			    => 'Historik',
    'history_for'  			=> 'Historie for',
    'id'  					=> 'ID',
    'image'                 => 'Billede',
    'image_delete'         	=> 'Slet billede',
    'image_upload'         	=> 'Upload billede',
    'image_filetypes_help'  => 'Accepted filetypes are jpg, webp, png, gif, and svg. Max upload size allowed is :size.',
    'import'         	    => 'Importér',
    'importing'         	=> 'Importerer',
    'importing_help'        => 'Du kan importere assets, tilbehør, licenser, komponenter, forbrugsvarer og brugere via CSV-fil. <br><br>CSV skal være kommasepareret og formateret med overskrifter, der matcher dem i <a href="https://snipe-it.readme.io/docs/importing" target="_new">sample CSV\'er i dokumentationen</a>.',
    'import-history'        => 'Importhistorik',
    'asset_maintenance'        => 'Vedligeholdelse af aktiv',
    'asset_maintenance_report' => 'Aktiv vedligeholdelsesrapport',
    'asset_maintenances'       => 'Vedligeholdelse af aktiv',
    'item'  				=> 'Emne',
    'insufficient_permissions' => 'Ingen rettigheder!',
    'kits'       			=> 'Prædefinerede Kits',
    'language'				=> 'Sprog',
    'last'					=> 'Sidste',
    'last_login'            => 'Sidste login',
    'last_name'             => 'Efternavn',
    'license'				=> 'Licens',
    'license_report'        => 'Licensrapport',
    'licenses_available'	=> 'Tilgængelige licenser',
    'licenses'				=> 'Licenser',
    'list_all'				=> 'Vis alle',
    'loading'				=> 'Indlæser',
    'lock_passwords'        => 'Feltværdien vil ikke blive gemt i en demoinstallation.',
    'feature_disabled'      => 'Denne funktion er blevet deaktiveret til demoinstallationen.',
    'location'              => 'Lokation',
    'locations'				=> 'Lokationer',
    'logo_size'				=> 'Kvadratiske logoer ser bedst ud som Logo + Text. Logo maksimum størrelse er 50px høj x 500px bred.  ',
    'logout'				=> 'Log ud',
    'lookup_by_tag'     => 'Søg på aktivkode',
    'maintenances'          => 'Vedligeholdelse',
    'manufacturer'			=> 'Producent',
    'manufacturers'			=> 'Producenter',
    'markdown'				=> 'Dette felt tillader <a href="https://help.github.com/articles/github-flavored-markdown/">Github koder</a>.',
    'min_amt'				=> 'Min. antal',
    'min_amt_help'	=> 'Minimum antal elementer, der skal være tilgængelige, før en advarsel udløses.',
    'model_no'				=> 'Modelnummer',
    'months'				=> 'måneder',
    'moreinfo'				=> 'Mere Info',
    'name'					=> 'Navn',
    'next'					=> 'Næste',
    'next_audit_date'		=> 'Næste revisionsdato',
    'last_audit'		    => 'Seneste revision',
    'new'					=> 'ny!',
    'no_depreciation'		=> 'Ingen Afskrivning',
    'no_results'			=> 'Ingen Resultater.',
    'no'  					=> 'Nej',
    'notes'  				=> 'Noter',
    'order_number'          => 'Ordrenummer',
    'page_menu'				=> 'Viser _MENU_ emner',
    'pagination_info'		=> 'Viser _START_ til _END_ af _TOTAL_ emner',
    'pending'				=> 'Afventer',
    'people'				=> 'Personer',
    'per_page'				=> 'Resultater Per Side',
    'previous'				=> 'Forrige',
    'processing'			=> 'Behandler',
    'profile'				=> 'Din profil',
    'purchase_cost'                              => 'Købsomkostninger',
    'purchase_date'         => 'Købsdato',
    'qty'		            => 'STK',
    'quantity'		        => 'Antal',
    'ready_to_deploy'		=> 'Klar til Implementering',
    'recent_activity'		=> 'Seneste aktivitet',
    'remove_company'        => 'Fjern association med selskab',
    'reports'				=> 'Rapporter',
    'restored'				=> 'gendannet',
    'requested'				=> 'Anmodet',
    'request_canceled'      => 'Anmodning Annulleret',
    'save'  				=> 'Gem',
    'select'				=> 'Vælg',
    'search'				=> 'Søg',
    'select_category'       => 'Vælg en kategori',
    'select_department'       => 'Vælg en afdeling',
    'select_depreciation'	=> 'Vælg en afskrivningstype',
    'select_location'		=> 'Vælg en placering',
    'select_manufacturer'	=> 'Vælg en producent',
    'select_model'			=> 'Vælg en model',
    'select_supplier'		=> 'Vælg en leverandør',
    'select_user'			=> 'Vælg en bruger',
    'select_date'			=> 'Vælg dato (ÅÅÅÅ-MM-DD)',
    'select_statuslabel'	=> 'Vælg Status',
    'select_company'    	=> 'Vælg firma',
    'select_asset'    		=> 'Vælg Asset',
    'settings'				=> 'Instillinger',
    'show_deleted'  		=> 'Vis slettede',
    'show_current'  		=> 'Vis Aktuelle',
    'sign_in'				=> 'Log ind',
    'signature'             => 'Underskrift',
    'skin'       			=> 'Skin',
    'slack_test_msg'        => 'Åh hai! Det ser ud til, at din Slack integration med Snipe-IT virker!',
    'some_features_disabled' => 'DEMO MODE: Nogle funktioner er deaktiveret for denne installation.',
    'site_name'				=> 'Site Navn',
    'state'  				=> 'Stat',
    'status_labels'			=> 'Status labels',
    'status'    			=> 'Status',
    'supplier'              => 'Leverandør',
    'suppliers'  			=> 'Leverandører',
    'sure_to_delete'    => 'Er du sikker på, at du vil slette',
    'submit'				=> 'Indsend',
    'target'                => 'Mål',
    'time_and_date_display' => 'Tid og datovisning',
    'total_assets'			=> 'totale aktiver',
    'total_licenses'		=> 'totale licenser',
    'total_accessories'		=> 'samlet tilbehør',
    'total_consumables'		=> 'samlede forbrugsstoffer',
    'type'  				=> 'Type',
    'undeployable'			=> 'Ikke implementerbar',
    'unknown_admin'			=> 'Ukendt Admin',
    'username_format'		=> 'Brugernavn Format',
    'update'                => 'Opdatering',
    'upload_filetypes_help'      => 'Tilladte filtyper er png, gif, jpg, jpeg, doc, docx, pdf, xls, txt, lic, zip, og rar. Maksimalt tilladte uploadstørrelse er :size.',
    'uploaded'              => 'uploaded',
    'user'					=> 'Bruger',
    'accepted'			    => 'accepteret',
    'declined'			    => 'faldt',
    'unaccepted_asset_report' => 'Uaccepterede aktiver',
    'users'                 => 'Brugere',
    'viewall'				=> 'Vis alle',
    'viewassets'  			=> 'Se Tildelte Aktiver',
    'website'               => 'Hjemmeside',
    'welcome'				=> 'Velkommen, :name',
    'years'					=> 'år',
    'yes' 					=> 'Ja',
    'zip'  					=> 'Postnummer',
    'noimage'				=> 'Intet billede uploadet eller billede ikke fundet.',
    'token_expired'         => 'Din form session er udløbet. Prøv igen.',
    'login_enabled'         => 'Login aktiveret',
    'audit_due'             => 'Forfalder til tilsyn',
    'audit_overdue'         => 'Forfalden til tilsyn',
    'accept'                => 'Accepter :asset',
    'i_accept'              => 'Jeg accepterer',
    'i_decline'             => 'Jeg afviser',
    'sign_tos'              => 'Bekræft nedenfor for at angive, at du accepterer vilkårene for tjenesten:',
    'clear_signature'       => 'Ryd signatur',
    'show_help'             => 'Show help',
    'hide_help'             => 'Hide help',
    ];

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/da/general.php <==
<?php

    return [
    'accessories'			=> 'Tilbehør',
    'activated'			    => 'Aktiveret',
    'accessory'				=> 'Tilbehør',
    'accessory_report'		=> 'Tilbehørsrapport',
    'action'                => 'Handling',
    'activity_report'		=> 'Aktivitetsrapport',
    'address'				=> 'Addresse',
    'admin'					=> 'Admin',
    'administrator'			=> 'Administrator',
    'add_seats'             => 'Tilføjede pladser',
    'all_assets'			=> 'Alle aktiver',
    'all'       			=> 'Alle',
    'archived'              => 'Arkiveret',
    'asset_models'			=> 'Aktiv Modeller',
    'asset_model'			=> 'Model',
    'asset'					=> 'Aktiv',
    'asset_report'          => 'Aktiv Rapport',
    'asset_tag'				=> 'Aktiv Mærkat',
    'asset_tags'            => 'Asset Tags',
    'assets_available'		=> 'Assets available',
    'accept_assets'         => 'Accept Assets :name',
    'accept_assets_menu'    => 'Accept Assets',
    'audit'				    => 'Revidere',
    'audit_report'			=> 'Revisionslog',
    'assets'				=> 'Aktiver',
    'avatar_delete'         => 'Slet avatar',
    'avatar_upload'         => 'Upload Avatar',
    'back'      			=> 'Tilbage',
    'bad_data'      		=> 'Intet fundet. Måske dårlig data?',
    'bulkaudit'             => 'Bulk Audit',
    'bulkaudit_status'      => 'Revisionsstatus',
    'bulk_checkout'  		=> 'Masseudtjekning',
    'bulk_edit'             => 'Bulk Edit',
    'bulk_delete'           => 'Bulk Delete',
    'bulk_actions'          => 'Bulk Actions',
    'bulk_checkin_delete'   => 'Bulk Checkin &amp; Delete',
    'bystatus'              => 'efter status',
    'cancel'  				=> 'Annuller',
    'categories'			=> 'Kategorier',
    'category'				=> 'Kategori',
    'change' 		        => 'Ind ud',
    'changeemail'  			=> 'Skift email adresse',
    'changepassword'  		=> 'Skift adgangskode',
    'checkin'  				=> 'Tjek Ind',
    'checkin_from'  		=> 'Tjek ind fra',
    'checkout'  			=> 'Tjek Ud',
    'checkouts_count'       => 'Checkouts',
    'checkins_count'        => 'Checkins',
    'user_requests_count'   => 'Forespørgsler',
    'city'  				=> 'By',
    'click_here'			=> 'Klik her',
    'clear_selection'		=> 'Ryd valg',
    'companies'			    => 'Selskaber',
    'company'				=> 'Selskab',
    'component'			    => 'Komponent',
    'components'			=> 'Komponenter',
    'complete'				=> 'Komplet',
    'consumable'			=> 'forbrugsmateriale',
    'consumables'			=> 'Forbrugsstoffer',
    'country'  				=> 'Land',
    'create'				=> 'Opret ny',
    'created'               => 'Elementet er oprettet',
    'created_asset'			=> 'skabte aktiver',
    'created_at' 			=> 'Skabt den',
    'record_created' 		=> 'Record dannet',
    'updated_at' 			=> 'Opdateret kl',
    'currency'  			=> '$', // this is deprecated
    'current'  				=> 'Aktuelle',
    'current_password'      => 'Current Password',
    'customize_report'      => 'Customize Report',
    'custom_report'         => 'Tilpasset Aktiv Rapport',
    'dashboard'				=> 'Oversigtspanel',
    'days'      			=> 'dage',
    'days_to_next_audit'    => 'Dage til næste revision',
    'date'					=> 'Dato',
    'debug_warning'         => 'Advarsel!',
    'debug_warning_text'    => 'Denne applikation kører i produktionstilstand med debugging aktiveret. Dette kan udsætte følsomme data, hvis din ansøgning er tilgængelig for omverdenen. Deaktiver fejlsøgningsmodus ved at indstille værdien <code>APP_DEBUG</code> i din <code>.env</code> fil til <code>false</code>.',
    'delete'  				=> 'Slet',
    'delete_confirm'  		=> 'Er du sikker på at du vil slette :item?',
    'deleted'  				=> 'Slettet',
    'delete_seats'  		=> 'Slettede pladser',
    'deletion_failed'       => 'Deletion failed',
    'departments'           => 'Afdelinger',
    'department'            => 'Afdeling',
    'deployed'				=> 'Implementeret',
    'depreciation'			=> 'Afskrivning',
    'depreciations'         => 'Depreciations',
    'depreciation_report'	=> 'Afskrivningsrapport',
    'details'               => 'Detaljer',
    'download'				=> 'Hent',
    'download_all'		    => 'Download alt',
    'editprofile'  			=> 'Ret Din Profil',
    'eol'					=> 'EOL',
    'email_domain'			=> 'Email domæne',
    'email_format'			=> 'Email formattering',
    'employee_number'       => 'Employee Number',
    'email_domain_help'		=> 'Dette bruges til at generere email-adresser ved importering',
    'error'				    => 'Error',
    'filastname_format'			=> 'Fornavnskarakter Efternavn (jsmith@example.com)',
    'firstname_lastname_format'	=> 'Fornavn Efternavn (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'Fornavn Efternavn (jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  'Efternavn Første initial (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'Første bogstav i fornavn efternavn (jsmith@example.com)',
    'first'					=> 'Første',
    'firstnamelastname'     => 'Fornavn efternavn (janesmith@example.com)',
    'lastname_firstinitial' => 'Efternavn første bogstav i fornavn (smith_j@example.com)',
    'firstinitial.lastname' => 'Første bogstav i fornavn.efternavn (j.smith@example.com)',
    'firstnamelastinitial'  => 'Fornavn førstebogstav i efternavn (janes@example.com)',
    'first_name'			=> 'Fornavn',
    'first_name_format'		=> 'Fornavn (jane@example.com)',
    'files'                 => 'Filer',
    'file_name'				=> 'Fil',
    'file_type'             => 'Filtype',
    'file_uploads'			=> 'Filoverførsel',
    'file_upload'           => 'File Upload',
    'generate'				=> 'Skab',
    'generate_labels'       => 'Generate Labels',
    'github_markdown'      => 'Dette felt tillader <a href="https://help.github.com/articles/github-flavored-markdown/">Github flavored markdown</a>.',
    'groups'				=> 'Grupper',
    'gravatar_email'        => 'Gravatar email addresse',
    'gravatar_url'          => '<a href="http://gravatar.com"><small>Change your avatar at Gravatar.com</small></a>.',
    'history'  			    => 'Historik',
    'history_for'  			=> 'Historie for',
    'id'  					=> 'ID',
    'image'                 => 'Billede',
    'image_delete'         	=> 'Slet billede',
    'image_upload'         	=> 'Upload billede',
    'filetypes_accepted_help'    => 'Accepted filetype is :types. Max upload size allowed is :size.|Accepted filetypes are :types. Max upload size allowed is :size.',
    'filetypes_size_help'   => 'Max upload size allowed is :size.',
    'image_filetypes_help'  => 'Tilladte filtyper er jpg, png, gif, og svg. Maximalt tilladte upload størrelse er :size.',
    'import'         	    => 'Importér',
    'importing'         	=> 'Importerer',
    'importing_help'        => 'Du kan importere assets, tilbehør, licenser, komponenter, forbrugsvarer og brugere via CSV-fil. <br><br>CSV skal være kommasepareret og formateret med overskrifter, der matcher dem i <a href="https://snipe-it.readme.io/docs/importing" target="_new">sample CSV\'er i dokumentationen</a>.',
    'import-history'        => 'Importhistorik',
    'asset_maintenance'        => 'Vedligeholdelse af aktiv',
    'asset_maintenance_report' => 'Aktiv vedligeholdelsesrapport',
    'asset_maintenances'       => 'Vedligeholdelse af aktiv',
    'item'  				=> 'Emne',
    'item_name'             => 'Item Name',
    'insufficient_permissions' => 'Ingen rettigheder!',
    'kits'       			=> 'Prædefinerede Kits',
    'language'				=> 'Sprog',
    'last'					=> 'Sidste',
    'last_login'            => 'Sidste login',
    'last_name'             => 'Efternavn',
    'license'				=> 'Licens',
    'license_report'        => 'Licensrapport',
    'licenses_available'	=> 'Tilgængelige licenser',
    'licenses'				=> 'Licenser',
    'list_all'				=> 'Vis alle',
    'loading'				=> 'Loading... please wait....',
    'lock_passwords'        => 'Feltværdien vil ikke blive gemt i en demoinstallation.',
    'feature_disabled'      => 'Denne funktion er blevet deaktiveret til demoinstallationen.',
    'location'              => 'Lokation',
    'locations'				=> 'Lokationer',
    'logo_size'				=> 'Kvadratiske logoer ser bedst ud som Logo + Text. Logo maksimum størrelse er 50px høj x 500px bred.  ',
    'logout'				=> 'Log ud',
    'lookup_by_tag'     => 'Søg på aktivkode',
    'maintenances'          => 'Vedligeholdelse',
    'manage_api_keys'       => 'Manage API Keys',
    'manufacturer'			=> 'Producent',
    'manufacturers'			=> 'Producenter',
    'markdown'				=> 'Dette felt tillader <a href="https://help.github.com/articles/github-flavored-markdown/">Github koder</a>.',
    'min_amt'				=> 'Min. antal',
    'min_amt_help'          => 'Minimum number of items that should be available before an alert gets triggered. Leave Min. QTY blank if you do not want to receive alerts for low inventory.',
    'model_no'				=> 'Modelnummer',
    'months'				=> 'måneder',
    'moreinfo'				=> 'Mere Info',
    'name'					=> 'Navn',
    'new_password'          => 'New Password',
    'next'					=> 'Næste',
    'next_audit_date'		=> 'Næste revisionsdato',
    'last_audit'		    => 'Seneste revision',
    'new'					=> 'ny!',
    'no_depreciation'		=> 'Ingen Afskrivning',
    'no_results'			=> 'Ingen Resultater.',
    'no'  					=> 'Nej',
    'notes'  				=> 'Noter',
    'order_number'          => 'Ordrenummer',
    'page_menu'				=> 'Viser _MENU_ emner',
    'pagination_info'		=> 'Viser _START_ til _END_ af _TOTAL_ emner',
    'pending'				=> 'Afventer',
    'people'				=> 'Personer',
    'per_page'				=> 'Resultater Per Side',
    'previous'				=> 'Forrige',
    'processing'			=> 'Behandler',
    'profile'				=> 'Din profil',
    'purchase_cost'                              => 'Købsomkostninger',
    'purchase_date'         => 'Købsdato',
    'qty'		            => 'STK',
    'quantity'		        => 'Antal',
    'quantity_minimum'      => 'You have :count items below or almost below minimum quantity levels',
    'quickscan_checkin'  	=> 'Quick Scan Checkin',
    'quickscan_checkin_status'  	=> 'Checkin Status',
    'ready_to_deploy'		=> 'Klar til Implementering',
    'recent_activity'		=> 'Seneste aktivitet',
    'remaining'             => 'Remaining',
    'remove_company'        => 'Fjern association med selskab',
    'reports'				=> 'Rapporter',
    'restored'				=> 'gendannet',
    'restore'				=> 'Restore',
    'requestable_models'    => 'Requestable Models',
    'requested'				=> 'Anmodet',
    'requested_date'        => 'Requested Date',
    'requested_assets'      => 'Requested Assets',
    'requested_assets_menu' => 'Requested Assets',
    'request_canceled'      => 'Anmodning Annulleret',
    'save'  				=> 'Gem',
    'select'				=> 'Vælg',
    'select_all'            => 'Select All',
    'search'				=> 'Søg',
    'select_category'       => 'Vælg en kategori',
    'select_department'     => 'Vælg en afdeling',
    'select_depreciation'	=> 'Vælg en afskrivningstype',
    'select_location'		=> 'Vælg en placering',
    'select_manufacturer'	=> 'Vælg en producent',
    'select_model'			=> 'Vælg en model',
    'select_supplier'		=> 'Vælg en leverandør',
    'select_user'			=> 'Vælg en bruger',
    'select_date'			=> 'Vælg dato (ÅÅÅÅ-MM-DD)',
    'select_statuslabel'	=> 'Vælg Status',
    'select_company'    	=> 'Vælg firma',
    'select_asset'    		=> 'Vælg Asset',
    'settings'				=> 'Instillinger',
    'show_deleted'  		=> 'Vis slettede',
    'show_current'  		=> 'Vis Aktuelle',
    'sign_in'				=> 'Log ind',
    'signature'             => 'Underskrift',
    'skin'       			=> 'Skin',
    'slack_msg_note'        => 'A slack message will be sent',
    'slack_test_msg'        => 'Åh hai! Det ser ud til, at din Slack integration med Snipe-IT virker!',
    'some_features_disabled' => 'DEMO MODE: Nogle funktioner er deaktiveret for denne installation.',
    'site_name'				=> 'Site Navn',
    'state'  				=> 'Stat',
    'status_labels'			=> 'Status labels',
    'status'    			=> 'Status',
    'supplier'              => 'Leverandør',
    'suppliers'  			=> 'Leverandører',
    'sure_to_delete'    => 'Er du sikker på, at du vil slette',
    'submit'				=> 'Indsend',
    'target'                => 'Mål',
    'toggle_navigation'     => 'Toogle Navigation',
    'time_and_date_display' => 'Tid og datovisning',
    'total_assets'			=> 'totale aktiver',
    'total_licenses'		=> 'totale licenser',
    'total_accessories'		=> 'samlet tilbehør',
    'total_consumables'		=> 'samlede forbrugsstoffer',
    'type'  				=> 'Type',
    'undeployable'			=> 'Ikke implementerbar',
    'unknown_admin'			=> 'Ukendt Admin',
    'username_format'		=> 'Brugernavn Format',
    'update'                => 'Opdatering',
    'upload_filetypes_help'      => 'Tilladte filtyper er png, gif, jpg, jpeg, doc, docx, pdf, xls, txt, lic, zip, og rar. Maksimalt tilladte uploadstørrelse er :size.',
    'uploaded'              => 'uploaded',
    'user'					=> 'Bruger',
    'accepted'			    => 'accepteret',
    'declined'			    => 'faldt',
    'unaccepted_asset_report' => 'Uaccepterede aktiver',
    'users'                 => 'Brugere',
    'viewall'				=> 'Vis alle',
    'viewassets'  			=> 'Se Tildelte Aktiver',
    'viewassetsfor'         => 'View Assets for :name',
    'website'               => 'Hjemmeside',
    'welcome'				=> 'Velkommen, :name',
    'years'					=> 'år',
    'yes' 					=> 'Ja',
    'zip'  					=> 'Postnummer',
    'noimage'				=> 'Intet billede uploadet eller billede ikke fundet.',
    'token_expired'         => 'Din form session er udløbet. Prøv igen.',
    'login_enabled'         => 'Login aktiveret',
    'audit_due'             => 'Forfalder til tilsyn',
    'audit_overdue'         => 'Forfalden til tilsyn',
    'accept'                => 'Accepter :asset',
    'i_accept'              => 'Jeg accepterer',
    'i_decline'             => 'Jeg afviser',
    'accept_decline'        => 'Accept/Decline',
    'sign_tos'              => 'Bekræft nedenfor for at angive, at du accepterer vilkårene for tjenesten:',
    'clear_signature'       => 'Ryd signatur',
    'show_help'             => 'Vis hjælp',
    'hide_help'             => 'Skjul hjælp',
    'view_all'              => 'view all',
    'hide_deleted'          => 'Hide Deleted',
    'email'                 => 'Email',
    'do_not_change'         => 'Do Not Change',
    'bug_report'            => 'Report a Bug',
    'user_manual'           => 'User\'s Manual',
    'setup_step_1'          => 'Step 1',
    'setup_step_2'          => 'Step 2',
    'setup_step_3'          => 'Step 3',
    'setup_step_4'          => 'Step 4',
    'setup_config_check'    => 'Configuration Check',
    'setup_create_database' => 'Create Database Tables',
    'setup_create_admin'    => 'Create Admin User',
    'setup_done'            => 'Finished!',
    'bulk_edit_about_to'    => 'You are about to edit the following: ',
    'checked_out'           => 'Checked Out',
    'checked_out_to'        => 'Checked out to',
    'fields'                => 'Fields',
    'last_checkout'         => 'Last Checkout',
    'due_to_checkin'        => 'The following :count items are due to be checked in soon:',
    'expected_checkin'      => 'Expected Checkin',
    'reminder_checked_out_items' => 'This is a reminder of the items currently checked out to you. If you feel this list is inaccurate (something is missing, or something appears here that you believe you never received), please email :reply_to_name at :reply_to_address.',
    'changed'               => 'Changed',
    'to'                    => 'To',
    'report_fields_info'    => '<p>Select the fields you would like to include in your custom report, and click Generate. The file (custom-asset-report-YYYY-mm-dd.csv) will download automatically, and you can open it in Excel.</p>
            <p>If you would like to export only certain assets, use the options below to fine-tune your results.</p>',
    'range'                 => 'Range',
    'bom_remark'            => 'Add a BOM (byte-order mark) to this CSV',
    'improvements'          => 'Improvements',
    'information'           => 'Information',
    'permissions'           => 'Permissions',
    'managed_ldap'          => '(Managed via LDAP)',
    'export'                => 'Export',
    'ldap_sync'             => 'LDAP Sync',
    'ldap_user_sync'        => 'LDAP User Sync',
    'synchronize'           => 'Synchronize',
    'sync_results'          => 'Synchronization Results',
    'license_serial'        => 'Serial/Product Key',
    'invalid_category'      => 'Invalid category',
    'dashboard_info'        => 'This is your dashboard. There are many like it, but this one is yours.',
    '60_percent_warning'    => '60% Complete (warning)',
    'dashboard_empty'       => 'It looks like you haven not added anything yet, so we do not have anything awesome to display. Get started by adding some assets, accessories, consumables, or licenses now!',
    'new_asset'             => 'New Asset',
    'new_license'           => 'New License',
    'new_accessory'         => 'New Accessory',
    'new_consumable'        => 'New Consumable',
    'collapse'              => 'Collapse',
    'assigned'              => 'Assigned',
    'asset_count'           => 'Asset Count',
    'accessories_count'     => 'Accessories Count',
    'consumables_count'     => 'Consumables Count',
    'components_count'      => 'Components Count',
    'licenses_count'        => 'Licenses Count',
    'notification_error'    => 'Error:',
    'notification_error_hint' => 'Please check the form below for errors',
    'notification_success'  => 'Success:',
    'notification_warning'   => 'Warning:',
    'notification_info'      => 'Info:',
    'asset_information'     => 'Asset Information',
    'model_name'            => 'Model Name:',
    'asset_name'            => 'Asset Name:',
    'consumable_information' => 'Consumable Information:',
    'consumable_name'       => 'Consumable Name:',
    'accessory_information' => 'Accessory Information:',
    'accessory_name'       => 'Accessory Name:',
    'clone_item'            => 'Clone Item',
    'checkout_tooltip' => 'Check this item out',
    'checkin_tooltip' => 'Check this item in',
    'checkout_user_tooltip' => 'Check this item out to a user',
];
